==> xmms-mad_0.7.orig.tar.gz: xmms-mad-0.7/src/xmms-mad.h <==
/*
 * xmms-mad - mp3 plugin for xmms
 * Copyright (C) 2001-2002 Sam Clegg - See COPYING
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 * $superduper: xmms-mad.h,v 1.7 2004/10/30 10:20:05 sam Exp $
 */
#ifndef XMMS_MAD_H
#define XMMS_MAD_H

#define G_LOG_DOMAIN "xmms-mad"

#include <stdlib.h>
#include <stdio.h>
#include <string.h>
#include <unistd.h>
#include <xmms/plugin.h>
#include <xmms/titlestring.h>
#include <id3tag.h>
#include <mad.h>

#include "xing.h"

struct mad_info_t
{
  /* flags */
  gint stop;
  gint seek;		/**< seek time in seconds */

  /* state */
  guint current_frame;	/**< current mp3 frame */
  mad_timer_t pos;	/**< current play position */

  /* song info */
  guint vbr;		/**< bool: is vbr? */
  guint bitrate;	/**< avg. bitrate */
  guint freq;		/**< sample freq. */
  guint mpeg_layer;	/**< mpeg layer */
  guint mode;		/**< mpeg stereo mode */
  guint channels;
  gint frames;          /**< total mp3 frames or -1 */
  gint fmt;             /**< sample format */
  gint size;            /**< file size in bytes or -1 */
  gchar *title;         /**< title for xmms */
  mad_timer_t duration; /**< total play time */
  struct id3_tag *tag;
  struct id3_file *id3file;
  struct xing xing;

  /* data access */
  gchar *url;
  gchar *filename;
  gint infile;
  gint offset;

  gint remote;
  struct streamdata_t *sdata; /**< stream data for remote connections */
};

struct xmmsmad_config_t
{
  gint http_buffer_size;
  gboolean fast_play_time_calc;
  gboolean use_xing;
  gboolean dither;
};

extern void *decode (void *arg);
extern void xmmsmad_error (gchar *fmt, ...);
extern void xmmsmad_configure ();
extern InputPlugin mad_plugin;        /**< the plugin itself */
extern struct xmmsmad_config_t xmmsmad_config;

#endif /* !XMMS_MAD_H */

==> xmms-mad_0.10.orig.tar.gz: xmms-mad-0.10/src/xmms-mad.h <==
/*
 * xmms-mad - mp3 plugin for xmms
 * Copyright (C) 2001-2002 Sam Clegg - See COPYING
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 * $superduper: xmms-mad.h,v 1.9 2005/03/12 01:09:57 sam Exp $
 */
#ifndef XMMS_MAD_H
#define XMMS_MAD_H

#define G_LOG_DOMAIN "xmms-mad"

#include <stdlib.h>
#include <stdio.h>
#include <string.h>
#include <unistd.h>
#include <xmms/plugin.h>
#include <xmms/titlestring.h>
#include <id3tag.h>
#include <mad.h>

#include "xing.h"

struct mad_info_t
{
  /* flags */
  guchar stop;
  gint seek;		/**< seek time in seconds */

  /* state */
  guint current_frame;	/**< current mp3 frame */
  mad_timer_t pos;	/**< current play position */

  /* song info */
  guint vbr;		/**< bool: is vbr? */
  guint bitrate;	/**< avg. bitrate */
  guint freq;		/**< sample freq. */
  guint mpeg_layer;	/**< mpeg layer */
  guint mode;		/**< mpeg stereo mode */
  guint channels;
  gint frames;          /**< total mp3 frames or -1 */
  gint fmt;             /**< sample format */
  gint size;            /**< file size in bytes or -1 */
  gchar *title;         /**< title for xmms */
  mad_timer_t duration; /**< total play time */
  struct id3_tag *tag;
  struct id3_file *id3file;
  struct xing xing;

  /* replay parameters */
  gboolean has_replaygain;
  double replaygain_album_scale;// -1 if not set
  double replaygain_track_scale;
  gchar *replaygain_album_str;
  gchar *replaygain_track_str;
  double replaygain_album_peak;// -1 if not set
  double replaygain_track_peak;
  gchar *replaygain_album_peak_str;
  gchar *replaygain_track_peak_str;
  double mp3gain_undo;// -1 if not set
  double mp3gain_minmax;
  gchar *mp3gain_undo_str;
  gchar *mp3gain_minmax_str;

  /* data access */
  gchar *url;
  gchar *filename;
  gint infile;
  gint offset;

  gint remote;
  struct streamdata_t *sdata; /**< stream data for remote connections */
};

struct xmmsmad_config_t
{
  gint http_buffer_size;
  gboolean fast_play_time_calc;
  gboolean use_xing;
  gboolean dither;
  gboolean hard_limit;
  gchar*  pregain_db; // gain applied to samples at decoding stage.
  gdouble pregain_scale; // pow(10, pregain/20)
  struct {
    gboolean enable;
    gboolean track_mode;
    gchar*  default_db; // gain used if no RG.
    gdouble default_scale;
  } replaygain;
};

void xmmsmad_config_compute(struct xmmsmad_config_t * config);
// compute scale values from "_db" strings

extern void *decode (void *arg);
extern void xmmsmad_error (gchar *fmt, ...);
extern void xmmsmad_configure ();
extern InputPlugin mad_plugin;        /**< the plugin itself */
extern struct xmmsmad_config_t xmmsmad_config;

#endif /* !XMMS_MAD_H */
